==> cucumber-groovy-1.2.3-sources.jar: cucumber/api/groovy/SR_LATN.java <==
package cucumber.api.groovy;

import groovy.lang.Closure;
import cucumber.runtime.groovy.*;

import java.util.regex.Pattern;

public class SR_LATN {

    public static void Ali(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Ali(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void I(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void I(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Kad(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Kad(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Kada(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Kada(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Onda(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Onda(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Zadate(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Zadate(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Zadato(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Zadato(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Zatati(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Zatati(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

}

==> cucumber-groovy-2.0.1-sources.jar: cucumber/api/groovy/SR_LATN.java <==
package cucumber.api.groovy;

import groovy.lang.Closure;
import cucumber.runtime.groovy.*;

import java.util.regex.Pattern;

public class SR_LATN {

    public static void Zadato(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Zadato(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Zadate(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Zadate(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Zadati(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Zadati(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Kada(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Kada(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Kad(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Kad(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Onda(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Onda(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void I(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void I(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Ali(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Ali(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

}
